@@ -14,11 +14,11 @@ class FglrxDriver(XorgDriverHandler):
         self._free = False
         XorgDriverHandler.__init__(self, backend, 'fglrx', 'xorg-driver-fglrx',
             'fglrx', 'ati', add_modules=['glx'], disable_modules=[],
-            name=_('ATI/AMD proprietary FGLRX graphics driver'),
+            name=_('AMD proprietary FGLRX graphics driver'),
             description=_('3D-accelerated proprietary graphics driver for '
-                'ATI cards.'),
+                'AMD (ATI) cards.'),
             rationale=_('This driver is required to fully utilise the 3D '
-                'potential of some ATI graphics cards, as well as provide '
+                'potential of some AMD (ATI) graphics cards, as well as provide '
                 '2D acceleration of newer cards.'))
 
     def enable_config_hook(self):
