@@ -439,6 +439,10 @@ class XMLRPCDriverDB(DriverDB):
         pos = u.find('://')
         if pos >= 0:
             u = u[(pos+3):]
+        else:
+            pos = u.find('file:/')
+            if pos >= 0:
+                u = u[(pos+5):]
         u = u.replace('/', '_')
 
         return DriverDB._cache_id(self) + '@' + u
@@ -736,7 +740,7 @@ def _driverid_to_handler(did, backend, mode):
             for h in backend.handler_pool.itervalues():
                 if isinstance(h, handlers.KernelModuleHandler) and \
                         h.module == did['kernel_module'] and \
-                        (not h.package or not did['package'] or h.package == did['package']):
+                        (not h.package or not 'package' in did or h.package == did['package']):
                     logging.debug('found match in handler pool %s', h)
                     del kwargs['kernel_module']
                     hclass = h.__class__
@@ -950,6 +954,10 @@ def get_handlers(backend, driverdb=None, handler_dir=None, mode=MODE_ANY,
 
             for name, obj in symb.iteritems():
                 try:
+                    # ignore private classes
+                    if name.startswith('_'):
+                        continue
+
                     # ignore non-Handler things; also ignore imports of
                     # standard base handlers into the global namespace
                     if not issubclass(obj, handlers.Handler) or \
