@@ -35,7 +35,7 @@ import subprocess, os.path, sys, logging
 from gettext import gettext as _
 
 import detection
-from oslib import OSLib
+from jockey.oslib import OSLib
 
 #--------------------------------------------------------------------#
 
@@ -53,6 +53,11 @@ class Handler:
         By default, available handlers are announced in
         AbstractUI.check(). If you want to have a handler which is
         available, but not announced that way, set self.annonuce to False.
+
+        If a handler needs to build a kernel module from source, it should set
+        self.needs_kernel_headers to True. Then the handler will try to install
+        the matching kernel header package for the currently running kernel.
+        (See OSLib.kernel_header_package).
         '''
         self._hwids = [] # covered HardwareIDs
         self._changed = False
@@ -63,6 +68,7 @@ class Handler:
         self._rationale = rationale
         self.license = None
         self.announce = True
+        self.needs_kernel_headers = False
 
         # the following properties are not specified in the ctor, since they
         # might be changed after instantiation;
@@ -241,6 +247,17 @@ class Handler:
         immediately successful, or False if the system needs to be rebooted for
         the changes to become effective.
         '''
+        # first ensure that the kernel header packages are installed, if
+        # requested
+        if self.needs_kernel_headers and OSLib.inst.kernel_header_package:
+            try:
+                self.backend.install_package(OSLib.inst.kernel_header_package)
+            except ValueError:
+                # package not available; most likely we have a custom kernel?
+                logging.error('enabling %s: Unable to install kernel header package %s',
+                        self.id(), OSLib.inst.kernel_header_package)
+                pass
+
         if self.package:
             self.backend.install_package(self.package, self.repository,
                     self.repository_sign_fp)
