@@ -67,10 +67,15 @@ class OSLib:
         # default path to custom handlers
         self.handler_dir = '/usr/share/jockey/handlers'
 
+        if target_kernel:
+            self.target_kernel = target_kernel
+        else:
+            self.target_kernel = os.uname()[2]
+
         # default paths to modalias files (directory entries will consider all
         # files in them)
         self.modaliases = [
-            '/lib/modules/%s/modules.alias' % os.uname()[2],
+            '/lib/modules/%s/modules.alias' % self.target_kernel,
             '/usr/share/jockey/modaliases/',
         ]
 
@@ -99,11 +104,6 @@ class OSLib:
         #self.gpg_key_server = 'keys.gnupg.net'
         self.gpg_key_server = 'hkp://keyserver.ubuntu.com:80'
 
-        if target_kernel:
-            self.target_kernel = target_kernel
-        else:
-            self.target_kernel = os.uname()[2]
-
         # Package which provides include files for the currently running
         # kernel.  If the system ensures that kernel headers are always
         # available, or being pulled in via dependencies (and there are not
@@ -152,10 +152,10 @@ class OSLib:
         # we send an "1" to select package if several versions 
         # are available (--filter is broken in at least Fedora 10)
         out = pkcon.communicate('1\n')[0]
-        m = re.search("^\s*description:\s*'?(.*?)'?$", out, re.M | re.S)
+        m = re.search("^\s*description:\s*'?(.*?)'?^\s+", out, re.M | re.S)
         if m:
             # TODO: short description (not accessible with pkcon)
-            return (package, m.group(1))
+            return (package, m.group(1).replace('\n', ''))
         else:
             raise ValueError('package %s does not exist' % package)
 
@@ -209,32 +209,37 @@ class OSLib:
         # this will check if the package exists
         self.package_description(package)
 
-        pkcon = subprocess.Popen(['pkcon', 'install', '-v', package],
-            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        pkcon = subprocess.Popen(['pkcon', 'install', '--plain', '-y', package],
+            stdin=subprocess.PIPE, stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE)
 
-        re_progress = re.compile('progress-changed (\d+), (\d+),')
+        # we send an "1" to select package if several versions
+        # are available
+        print >>pkcon.stdin, "1\n"
+
+        re_progress = re.compile('Percentage:\t(\d+)')
 
         phase = None
-        err = ''
+        err = line = ''
         fail = False
-        while pkcon.poll() == None:
+        while pkcon.poll() == None or line != '':
             line = pkcon.stdout.readline()
-            if line == '':
-                break
             if fail:
                 err += line
-            if 'status-changed download' in line:
+            if 'Downloading packages' in line:
                 phase = 'download'
-            elif 'status-changed commit' in line:
+            elif 'Testing changes' in line or 'Installing packages' in line:
                 phase = 'install'
-            elif progress_cb and 'progress-changed' in line:
+            elif progress_cb and 'Percentage' in line:
                 m = re_progress.search(line)
                 if m and phase:
-                    progress_cb(phase, int(m.group(1)), int(m.group(2)))
+                    progress_cb(phase, int(m.group(1)), 100)
                 else:
                     progress_cb(phase or 'download', -1, -1)
             elif 'WARNING' in line:
                 fail = True
+            elif 'transaction-error' in line or 'failed:' in line:
+                err += line
 
         err += pkcon.stderr.read()
         if pkcon.wait() != 0 or not self.package_installed(package):
@@ -253,30 +258,30 @@ class OSLib:
 
         Any removal failure should be raised as a SystemError.
         '''
-        pkcon = subprocess.Popen(['pkcon', 'remove', '-v', package],
+        pkcon = subprocess.Popen(['pkcon', 'remove', '--plain', '-y', package],
             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
 
-        re_progress = re.compile('progress-changed (\d+), (\d+),')
+        re_progress = re.compile('Percentage:\t(\d+)')
 
         have_progress = False
-        err = ''
+        err = line = ''
         fail = False
-        while pkcon.poll() == None:
+        while pkcon.poll() == None or line != '':
             line = pkcon.stdout.readline()
-            if line == '':
-                break
             if fail:
                 err += line
-            if 'status-changed remove' in line:
+            if 'Removing packages' in line:
                 have_progress = True
-            elif progress_cb and 'progress-changed' in line:
+            elif progress_cb and 'Percentage' in line:
                 m = re_progress.search(line)
                 if m and have_progress:
-                    progress_cb(int(m.group(1)), int(m.group(2)))
+                    progress_cb(int(m.group(1)), 100)
                 else:
                     progress_cb(-1, -1)
             elif 'WARNING' in line:
                 fail = True
+            elif 'transaction-error' in line or 'failed:' in line:
+                err += line
 
         err += pkcon.stderr.read()
         pkcon.wait()
@@ -541,13 +546,17 @@ class OSLib:
         if not os.path.exists(d):
             os.makedirs(d)
 
-        f = open(self.module_blacklist_file, 'w')
+        f = None
         try:
+            f = open(self.module_blacklist_file, 'w')
             fcntl.flock(f.fileno(), fcntl.LOCK_EX)
             for module in sorted(self._module_blacklist):
                 print >> f, 'blacklist', module
+        except IOError as e:
+            logging.error('Failed to write to module blacklist: ' + str(e))
         finally:
-            f.close()
+            if f:
+                f.close()
 
     def _get_os_version(self):
         '''Initialize self.os_vendor and self.os_version.
