@@ -114,10 +114,13 @@ class AbstractUI(dbus.service.Object):
                 else:
                     self._dbus_iface = Backend.create_dbus_client()
             except Exception as e:
-                if hasattr(e, '_dbus_error_name') and e._dbus_error_name == \
-                    'org.freedesktop.DBus.Error.FileNotFound':
+                if hasattr(e, '_dbus_error_name') and e._dbus_error_name in (
+                    'org.freedesktop.DBus.Error.FileNotFound',
+                    'org.freedesktop.DBus.Error.NoServer'):
                     if self.have_ui:
-                        self.error_message(self._('Cannot connect to D-BUS'),
+                        self.error_message(self._('Cannot connect to D-BUS,'+\
+                            ' please use the --no-dbus option as root to'+\
+                            ' use jockey without it.'),
                             str(e))
                     else:
                         self.error_msg(str(e))
@@ -568,7 +571,7 @@ class AbstractUI(dbus.service.Object):
         h_id = self.backend().check_composite()
 
         if h_id:
-            self.set_handler_enable(h_id, 'enable', True)
+            self.set_handler_enable(h_id, 'enable', self.argv_options.confirm)
             return bool(self.backend().handler_info(h_id)['enabled'])
 
         self.error_msg(self._('There is no available graphics driver for your system which supports the composite extension, or the current one already supports it.'))
@@ -1016,6 +1019,8 @@ class AbstractUI(dbus.service.Object):
         try:
             indicator = AppIndicator.Indicator.new('jockey', 'jockey',
                     AppIndicator.IndicatorCategory.HARDWARE)
+            indicator.set_icon_full('jockey', 
+                    self._('Restricted drivers available'))
         except Exception as e:
             raise NotImplementedError('appindicator support not available: %s' \
                 '\nsubclasses need to implement this' % str(e))
