@@ -16,7 +16,8 @@
 
 '''Abstract handler for a restricted X.org graphics driver.'''
 
-import os.path, logging
+import os.path, logging, re
+from glob import glob
 
 import XKit.xutils
 import XKit.xorgparser
@@ -357,3 +358,26 @@ class XorgDriverHandler(KernelModuleHandler):
 
         return False
 
+    @classmethod
+    def loaded_drivers(klass, log_dir='/var/log/'):
+        '''Return a set of graphics drivers loaded by X.org.'''
+
+        # find the most recent X.org log
+        log = None
+        max_time = 0
+        for f in glob(os.path.join(log_dir, 'Xorg.*.log')):
+            mtime = os.stat(f).st_mtime
+            if mtime > max_time:
+                max_time = mtime
+                log = f
+
+        drivers = set()
+        if not log:
+            return drivers
+
+        with open(log) as f:
+            for match in re.finditer('\(II\) Loading.*modules\/drivers\/(.+)_drv\.so', f.read()):
+                drivers.add(match.group(1))
+
+        return drivers
+
