@@ -488,8 +488,8 @@ class LocalBackendTest(sandbox.LogTestCase):
         self.assert_('printer:openprinting-ppds-postscript-hp:HP' not in b.available())
         self.assertEqual(b.search_driver(
             'printer_deviceid:MFG:Hewlett-Packard;MDL:HP DesignJet 3500CP'),
-            ['printer:openprinting-ppds-postscript-hp:Postscript-HP'])
-        self.assert_('printer:openprinting-ppds-postscript-hp:Postscript-HP' in b.available())
+            ['printer:openprinting-ppds-postscript-hp:20091009'])
+        self.assert_('printer:openprinting-ppds-postscript-hp:20091009' in b.available())
 
     def test_driver_search_redundancy(self):
         '''Backend.add_driverdb() and search_driver() avoid redundant actions'''
