@@ -217,6 +217,24 @@ kmod:vanilla3d([VanillaGfxHandler, nonfree, enabled] nonfree, replacement graphi
             else:
                 self.assert_(h.enabled())
 
+    def test_get_handlers_private_class(self):
+        '''get_handlers() ignores private base classes starting with _'''
+
+        open(os.path.join(OSLib.inst.handler_dir, 'kmod_baseclass.py'), 'w').write(
+            sandbox.h_privateclass_py)
+
+        log_offset = sandbox.log.tell()
+        h = jockey.detection.get_handlers(jockey.backend.Backend())
+        log = sandbox.log.getvalue()[log_offset:]
+
+        self.assertEqual(len(h), 1)
+        for h in h: pass # get single item in set h
+        self.assert_(isinstance(h, jockey.handlers.Handler))
+        self.assert_(h.available())
+        self.assertEqual(str(h.__class__).split('.')[-1], 'MyHandler')
+
+        self.failIf('Could not instantiate Handler' in log, log)
+
     def test_localkernelmod_driverdb(self):
         '''LocalKernelModulesDriverDB creates appropriate handlers
         
@@ -885,7 +903,8 @@ kmod:vanilla3d([VanillaGfxHandler, nonfree, enabled] nonfree, replacement graphi
         finally:
             OSLib.inst.packaging_system = orig_pkgsys
         handlers = backend.available()
-        self.assertEqual(handlers, ['printer:epson-inkjet-printer-n10-nx127:1.0.0'])
+        self.assertEqual(len(handlers), 1)
+        self.assertTrue(handlers[0].startswith('printer:epson-inkjet-printer-n10-nx127:1'))
 
         hi = backend.handler_info(handlers[0])
         self.assert_(hi['package'].startswith('epson-inkjet-'))
