@@ -1008,6 +1008,27 @@ EndSection
         finally:
             OSLib.inst.video_driver_abi = orig_video_driver_abi
 
+    def test_xorg_driver_loaded_drivers(self):
+        '''XorgDriverHandler.loaded_drivers()'''
+
+        # system one
+        drivers = XorgDriverHandler.loaded_drivers()
+        self.assertEqual(type(drivers), type(set()))
+        if 'DISPLAY' in os.environ:
+            self.assertGreaterEqual(len(drivers), 1)
+
+        # synthetic
+        with open(os.path.join(OSLib.inst.workdir, 'Xorg.1.log'), 'w') as f:
+            f.write('''X.Org X Server 1.10.4
+[    14.451] (II) LoadModule: "intel"
+[    14.452] (II) Loading /usr/lib/xorg/modules/drivers/intel_drv.so
+[    14.459] (II) LoadModule: "vesa"
+[    14.459] (II) Loading /usr/lib/xorg/modules/drivers/vesa_drv.so
+[    14.452] (II) Loading /usr/lib/xorg/modules/drivers/intel_drv.so
+''')
+        self.assertEqual(XorgDriverHandler.loaded_drivers(OSLib.inst.workdir),
+                set(['intel', 'vesa']))
+
     def test_firmware_handler(self):
         '''standard FirmwareHandler'''
 
