@@ -18,13 +18,13 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-import unittest, os, tempfile, shutil, urllib2, subprocess
+import unittest, os, tempfile, shutil, subprocess
 
 from jockey.oslib import OSLib
 import sandbox
-import http
+import httpd
 
-from jockey.detection import download_gpg_fingerprint
+import jockey.detection
 
 # fingerprint of tests/data/pubring.gpg
 test_gpg_fp = '4EF8 3174 F985 6BD6 0E8D  584C 1A2E C5F3 E6B6 0077'
@@ -217,7 +217,7 @@ class OSLibTest(sandbox.LogTestCase):
         if not cert:
             return self.skipTest('not available]')
 
-        fp = download_gpg_fingerprint(
+        fp = jockey.detection.download_gpg_fingerprint(
                 'https://linux.avasys.jp/drivers/lsb/epson-inkjet/key/fingerprint')
         self.assertNotEqual(fp, None)
 
@@ -288,12 +288,12 @@ class OSLibTest(sandbox.LogTestCase):
         assert subprocess.call(['gpg', '--homedir', dir, '--no-default-keyring',
             '--primary-keyring', os.path.join(os.path.dirname(__file__), 'data/pubring.gpg'),
             '--export', '-a'], stdout=lookup) == 0
-        http.start(11371, OSLib.inst.workdir)
+        httpd.start(11371, OSLib.inst.workdir)
 
     @classmethod
     def _stop_keyserver(klass):
         '''Stop the keyserver.'''
 
-        http.stop()
+        httpd.stop()
         shutil.rmtree(os.path.join(OSLib.inst.workdir, 'pks'))
 
