@@ -1358,6 +1358,7 @@ class NoDetectMod(jockey.handlers.KernelModuleHandler):
             description='Test suite: non-detectable kernel module')
 '''
 
+
 # complete .py file contents with above three handlers
 h_availability_py = 'import jockey.handlers\n%s\n%s\n%s\n' % (
     h_avail_mod, h_notavail_mod, h_nodetectmod)
@@ -1392,6 +1393,22 @@ class AutoInstallHandler(KernelModuleHandler):
         return True
 '''
 
+h_privateclass_py = '''
+import jockey.handlers
+
+class _MyHandlerBase(jockey.handlers.KernelModuleHandler):
+    def __init__(self, ui, param):
+        jockey.handlers.KernelModuleHandler.__init__(self, ui, 'spam',
+            description='Test suite: private base class')
+        self.param = param
+    def available(self):
+        return True
+
+class MyHandler(_MyHandlerBase):
+    def __init__(self, ui):
+        _MyHandlerBase.__init__(self, ui, 'foo')
+'''
+
 #-------------------------------------------------------------------#
 # other globals
 
