@@ -25,7 +25,7 @@ import jockey.ui, jockey.handlers
 from jockey.oslib import OSLib
 from jockey.xorg_driver import XorgDriverHandler
 
-import sandbox, http
+import sandbox, httpd
 
 class UITest(sandbox.LogTestCase):
     '''User interface tests.
@@ -601,9 +601,9 @@ class UITest(sandbox.LogTestCase):
         ui = sandbox.TestUI()
 
         # temporary file
-        http.start(8427, OSLib.inst.workdir)
+        httpd.start(8427, OSLib.inst.workdir)
         (fname, h) = ui.download_url('http://localhost:8427/stuff')
-        http.stop()
+        httpd.stop()
         self.assertEqual(open(fname).read(), self.big_file_contents)
         os.unlink(fname)
 
@@ -615,9 +615,9 @@ class UITest(sandbox.LogTestCase):
 
         # specified file name
         dest = os.path.join(OSLib.inst.workdir, 'destfile')
-        http.start(8427, OSLib.inst.workdir)
+        httpd.start(8427, OSLib.inst.workdir)
         (fname, h) = ui.download_url('http://localhost:8427/stuff', dest)
-        http.stop()
+        httpd.stop()
         self.assertEqual(fname, dest)
         self.assertEqual(open(dest).read(), self.big_file_contents)
         os.unlink(dest)
@@ -629,9 +629,9 @@ class UITest(sandbox.LogTestCase):
             len(self.big_file_contents), len(self.big_file_contents)])
 
         # nonexisting file
-        http.start(8427, OSLib.inst.workdir)
+        httpd.start(8427, OSLib.inst.workdir)
         (fname, h) = ui.download_url('http://localhost:8427/nonexisting')
-        http.stop()
+        httpd.stop()
         self.assertEqual(fname, None)
 
         # one error message about download failure
@@ -639,9 +639,9 @@ class UITest(sandbox.LogTestCase):
         self.assertRaises(IndexError, ui.pop_error)
 
         # nonexisting server
-        http.start(8427, OSLib.inst.workdir)
+        httpd.start(8427, OSLib.inst.workdir)
         (fname, h) = ui.download_url('http://i.do.not.exist:8080/nonexisting')
-        http.stop()
+        httpd.stop()
         self.assertEqual(fname, None)
 
         # one error message about download failure
@@ -656,10 +656,10 @@ class UITest(sandbox.LogTestCase):
         ui = sandbox.TestUI()
 
         # temporary file
-        http.start(8427, OSLib.inst.workdir)
+        httpd.start(8427, OSLib.inst.workdir)
         ui.cancel_progress = True
         (fname, h) = ui.download_url('http://localhost:8427/stuff')
-        http.stop()
+        httpd.stop()
         self.assertEqual(fname, None)
 
         self.assertRaises(IndexError, ui.pop_error)
@@ -673,9 +673,9 @@ class UITest(sandbox.LogTestCase):
         # specified file name
         dest = os.path.join(OSLib.inst.workdir, 'destfile')
         ui.cancel_progress = True
-        http.start(8427, OSLib.inst.workdir)
+        httpd.start(8427, OSLib.inst.workdir)
         (fname, h) = ui.download_url('http://localhost:8427/stuff', dest)
-        http.stop()
+        httpd.stop()
         self.assertEqual(fname, None)
 
         self.assertRaises(IndexError, ui.pop_error)
